@@ -36,7 +36,6 @@
 
 #include <algorithm>
 
-#include "RequestGroup.h"
 #include "Request.h"
 #include "DownloadEngine.h"
 #include "Option.h"
@@ -47,6 +46,7 @@
 #include "DlAbortEx.h"
 #include "DlRetryEx.h"
 #include "DownloadFailureException.h"
+#include "CreateRequestCommand.h"
 #include "InitiateConnectionCommandFactory.h"
 #include "SleepCommand.h"
 #ifdef ENABLE_ASYNC_DNS
@@ -62,16 +62,19 @@
 #include "RequestGroupMan.h"
 #include "A2STR.h"
 #include "Util.h"
+#include "LogFactory.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
 AbstractCommand::AbstractCommand(int32_t cuid,
 				 const SharedHandle<Request>& req,
+				 const SharedHandle<FileEntry>& fileEntry,
 				 RequestGroup* requestGroup,
 				 DownloadEngine* e,
 				 const SocketHandle& s):
   Command(cuid), _requestGroup(requestGroup),
-  req(req), e(e), socket(s),
+  req(req), _fileEntry(fileEntry), e(e), socket(s),
   checkSocketIsReadable(false), checkSocketIsWritable(false),
   nameResolverCheck(false)
 {
@@ -101,16 +104,24 @@ bool AbstractCommand::execute() {
       //logger->debug("CUID#%d - finished.", cuid);
       return true;
     }
-    PeerStatHandle peerStat;
-    if(!_requestGroup->getSegmentMan().isNull()) {
-      peerStat = _requestGroup->getSegmentMan()->getPeerStat(cuid);
-    }
-    if(!peerStat.isNull()) {
-      if(peerStat->getStatus() == PeerStat::REQUEST_IDLE) {
-	logger->info(MSG_ABORT_REQUESTED, cuid);
-	onAbort();
-	req->resetUrl();
-	tryReserved();
+    // TODO it is not needed to check other PeerStats every time.
+    // Find faster Request when this is the only active Request
+    if(!req.isNull() && _requestGroup->getNumStreamConnection() == 1 &&
+       _fileEntry->countPooledRequest() > 0) {
+      SharedHandle<Request> fasterRequest = _fileEntry->findFasterRequest(req);
+      if(!fasterRequest.isNull()) {
+	logger->info("CUID#%d - Use faster Request hostname=%s, port=%u",
+		     cuid,
+		     fasterRequest->getHost().c_str(),
+		     fasterRequest->getPort());
+
+	// Cancel current Request object and use faster one.
+	_fileEntry->removeRequest(req);
+	Command* command =
+	  InitiateConnectionCommandFactory::createInitiateConnectionCommand
+	  (cuid, fasterRequest, _fileEntry, _requestGroup, e);
+	e->setNoWait(true);
+	e->commands.push_back(command);
 	return true;
       }
     }
@@ -125,17 +136,35 @@ bool AbstractCommand::execute() {
       if(!_requestGroup->getPieceStorage().isNull()) {
 	_segments.clear();
 	_requestGroup->getSegmentMan()->getInFlightSegment(_segments, cuid);
-	while(_segments.size() < req->getMaxPipelinedRequest()) {
-	  SegmentHandle segment = _requestGroup->getSegmentMan()->getSegment(cuid);
-	  if(segment.isNull()) {
-	    break;
+	if(req.isNull() || req->getMaxPipelinedRequest() == 1 ||
+	   _requestGroup->getDownloadContext()->getFileEntries().size() == 1) {
+	  if(_segments.empty()) {
+	    SharedHandle<Segment> segment =
+	      _requestGroup->getSegmentMan()->getSegment(cuid);
+	    if(!segment.isNull()) {
+	      _segments.push_back(segment);
+	    }
+	  }
+	  if(_segments.empty()) {
+	    // TODO socket could be pooled here if pipelining is enabled...
+	    logger->info(MSG_NO_SEGMENT_AVAILABLE, cuid);
+	    // When all segments are ignored in SegmentMan, there are
+	    // no URIs available, so don't retry.
+	    if(_requestGroup->getSegmentMan()->allSegmentsIgnored()) {
+	      return true;
+	    } else {
+	      return prepareForRetry(1);
+	    }
+	  }
+	} else {
+	  size_t maxSegments = req->getMaxPipelinedRequest();
+	  if(_segments.size() < maxSegments) {
+	      _requestGroup->getSegmentMan()->getSegment
+	      (_segments, cuid, _fileEntry, maxSegments);
+	  }
+	  if(_segments.empty()) {
+	    return prepareForRetry(0);
 	  }
-	  _segments.push_back(segment);
-	}
-	if(_segments.empty()) {
-	  // TODO socket could be pooled here if pipelining is enabled...
-	  logger->info(MSG_NO_SEGMENT_AVAILABLE, cuid);
-	  return prepareForRetry(1);
 	}
       }
       return executeInternal();
@@ -146,47 +175,47 @@ bool AbstractCommand::execute() {
     } else {
       if(checkPoint.elapsed(timeout)) {
 	// timeout triggers ServerStat error state.
+
 	SharedHandle<ServerStat> ss =
 	  e->_requestGroupMan->getOrCreateServerStat(req->getHost(),
 						     req->getProtocol());
 	ss->setError();
 
-	throw DL_RETRY_EX2(EX_TIME_OUT, DownloadResult::TIME_OUT);
+	throw DL_RETRY_EX2(EX_TIME_OUT, downloadresultcode::TIME_OUT);
       }
       e->commands.push_back(this);
       return false;
     }
   } catch(DlAbortEx& err) {
-    logger->error(MSG_DOWNLOAD_ABORTED,
-		  DL_ABORT_EX2(StringFormat
-			      ("URI=%s", req->getCurrentUrl().c_str()).str(),err),
-		  cuid, req->getUrl().c_str());
-    _requestGroup->addURIResult(req->getUrl(), err.getCode());
+    if(req.isNull()) {
+      logger->debug(EX_EXCEPTION_CAUGHT, err);
+    } else {
+      logger->error(MSG_DOWNLOAD_ABORTED,
+		    DL_ABORT_EX2(StringFormat
+				 ("URI=%s", req->getCurrentUrl().c_str()).str(),err),
+		    cuid, req->getUrl().c_str());
+      _fileEntry->addURIResult(req->getUrl(), err.getCode());
+      _requestGroup->setLastUriResult(req->getUrl(), err.getCode());
+    }
     onAbort();
-    req->resetUrl();
     tryReserved();
     return true;
   } catch(DlRetryEx& err) {
+    assert(!req.isNull());
     logger->info(MSG_RESTARTING_DOWNLOAD,
 		 DL_RETRY_EX2(StringFormat
 			     ("URI=%s", req->getCurrentUrl().c_str()).str(),err),
 		 cuid, req->getUrl().c_str());
     req->addTryCount();
     req->resetRedirectCount();
-    bool isAbort = _requestGroup->getMaxTries() != 0 &&
-      req->getTryCount() >= _requestGroup->getMaxTries();
+    const unsigned int maxTries = getOption()->getAsInt(PREF_MAX_TRIES);
+    bool isAbort = maxTries != 0 && req->getTryCount() >= maxTries;
     if(isAbort) {
       onAbort();
-      req->resetUrl();
-    } else {
-      if(getOption()->getAsBool(PREF_RESET_URI)) {
-	req->resetUrl();
-      }
-    }
-    if(isAbort) {
       logger->info(MSG_MAX_TRY, cuid, req->getTryCount());
       logger->error(MSG_DOWNLOAD_ABORTED, err, cuid, req->getUrl().c_str());
-      _requestGroup->addURIResult(req->getUrl(), err.getCode());
+      _fileEntry->addURIResult(req->getUrl(), err.getCode());
+      _requestGroup->setLastUriResult(req->getUrl(), err.getCode());
       tryReserved();
       return true;
     } else {
@@ -194,14 +223,30 @@ bool AbstractCommand::execute() {
     }
   } catch(DownloadFailureException& err) {
     logger->error(EX_EXCEPTION_CAUGHT, err);
-    _requestGroup->addURIResult(req->getUrl(), err.getCode());
+    if(!req.isNull()) {
+      _fileEntry->addURIResult(req->getUrl(), err.getCode());
+      _requestGroup->setLastUriResult(req->getUrl(), err.getCode());
+    }
     _requestGroup->setHaltRequested(true);
     return true;
   }
 }
 
 void AbstractCommand::tryReserved() {
-  _requestGroup->removeServerHost(cuid);
+  if(_requestGroup->getDownloadContext()->getFileEntries().size() == 1) {
+    const SharedHandle<FileEntry>& entry =
+      _requestGroup->getDownloadContext()->getFirstFileEntry();
+    // Don't create new command if currently file length is unknown
+    // and there are no URI left. Because file length is unknown, we
+    // can assume that there are no in-flight request object.
+    if(entry->getLength() == 0 && entry->getRemainingUris().empty()) {
+      logger->debug("CUID#%d - Not trying next request."
+		    " No reserved/pooled request is remaining and"
+		    " total length is still unknown.", cuid);
+      return;
+    }
+  }
+  logger->debug("CUID#%d - Trying reserved/pooled request.", cuid);
   Commands commands;
   _requestGroup->createNextCommand(commands, e, 1);
   e->setNoWait(true);
@@ -212,7 +257,16 @@ bool AbstractCommand::prepareForRetry(time_t wait) {
   if(!_requestGroup->getPieceStorage().isNull()) {
     _requestGroup->getSegmentMan()->cancelSegment(cuid);
   }
-  Command* command = InitiateConnectionCommandFactory::createInitiateConnectionCommand(cuid, req, _requestGroup, e);
+  if(!req.isNull()) {
+    _fileEntry->poolRequest(req);
+    logger->debug("CUID#%d - Pooling request URI=%s",
+		  cuid, req->getUrl().c_str());
+    if(!_requestGroup->getSegmentMan().isNull()) {
+      _requestGroup->getSegmentMan()->recognizeSegmentFor(_fileEntry);
+    }
+  }
+
+  Command* command = new CreateRequestCommand(cuid, _requestGroup, e);
   if(wait == 0) {
     e->setNoWait(true);
     e->commands.push_back(command);
@@ -225,16 +279,19 @@ bool AbstractCommand::prepareForRetry(time_t wait) {
 }
 
 void AbstractCommand::onAbort() {
-  // TODO This might be a problem if the failure is caused by proxy.
-  e->_requestGroupMan->getOrCreateServerStat(req->getHost(),
-					     req->getProtocol())->setError();
+  if(!req.isNull()) {
+    logger->debug(req->getCurrentUrl().c_str());
+    // TODO This might be a problem if the failure is caused by proxy.
+    e->_requestGroupMan->getOrCreateServerStat(req->getHost(),
+					       req->getProtocol())->setError();
+    _fileEntry->removeIdenticalURI(req->getUrl());
+    _fileEntry->removeRequest(req);
+  }
 
-  logger->debug(MSG_UNREGISTER_CUID, cuid);
-  //_segmentMan->unregisterId(cuid);
+  logger->debug("CUID#%d - Aborting download", cuid);
   if(!_requestGroup->getPieceStorage().isNull()) {
     _requestGroup->getSegmentMan()->cancelSegment(cuid);
   }
-  _requestGroup->removeIdenticalURI(req->getUrl());
 }
 
 void AbstractCommand::disableReadCheckSocket() {
@@ -470,7 +527,8 @@ bool AbstractCommand::nameResolveFinished() const {
 
 void AbstractCommand::prepareForNextAction(Command* nextCommand)
 {
-  CheckIntegrityEntryHandle entry(new StreamCheckIntegrityEntry(req, _requestGroup, nextCommand));
+  CheckIntegrityEntryHandle entry
+    (new StreamCheckIntegrityEntry(_requestGroup, nextCommand));
 
   std::deque<Command*> commands;
   _requestGroup->processCheckIntegrityEntry(commands, entry, e);
@@ -479,12 +537,28 @@ void AbstractCommand::prepareForNextAction(Command* nextCommand)
   e->setNoWait(true);
 }
 
-void AbstractCommand::checkIfConnectionEstablished
-(const SharedHandle<SocketCore>& socket)
+bool AbstractCommand::checkIfConnectionEstablished
+(const SharedHandle<SocketCore>& socket,
+ const std::string& connectedHostname,
+ const std::string& connectedAddr,
+ uint16_t connectedPort)
 {
   if(socket->isReadable(0)) {
     std::string error = socket->getSocketError();
     if(!error.empty()) {
+      e->markBadIPAddress(connectedHostname, connectedAddr, connectedPort);
+      if(!e->findCachedIPAddress(connectedHostname, connectedPort).empty()) {
+	logger->info("CUID#%d - Could not to connect to %s:%u."
+		     " Trying another address",
+		     cuid, connectedAddr.c_str(), connectedPort);
+	Command* command =
+	  InitiateConnectionCommandFactory::createInitiateConnectionCommand
+	  (cuid, req, _fileEntry, _requestGroup, e);
+	e->setNoWait(true);
+	e->commands.push_back(command);
+	return false;
+      }
+      e->removeCachedIPAddress(connectedHostname, connectedPort);
       // Don't set error if proxy server is used and its method is GET.
       if(resolveProxyMethod(req->getProtocol()) != V_GET ||
 	 !isProxyRequest(req->getProtocol(), getOption())) {
@@ -495,6 +569,7 @@ void AbstractCommand::checkIfConnectionEstablished
 	(StringFormat(MSG_ESTABLISHING_CONNECTION_FAILED, error.c_str()).str());
     }
   }
+  return true;
 }
 
 const std::string& AbstractCommand::resolveProxyMethod
