@@ -49,12 +49,12 @@ namespace aria2 {
 BitfieldMan::BitfieldMan(size_t blockLength, uint64_t totalLength)
   :blockLength(blockLength),
    totalLength(totalLength),
-   bitfield(0),
-   useBitfield(0),
-   filterBitfield(0),
    bitfieldLength(0),
    blocks(0),
    filterEnabled(false),
+   bitfield(0),
+   useBitfield(0),
+   filterBitfield(0),
    cachedNumMissingBlock(0),
    cachedNumFilteredBlock(0),
    cachedCompletedLength(0),
@@ -73,36 +73,27 @@ BitfieldMan::BitfieldMan(size_t blockLength, uint64_t totalLength)
 }
 
 BitfieldMan::BitfieldMan(const BitfieldMan& bitfieldMan)
-  :blockLength(0),
-   totalLength(0),
-   bitfield(0),
-   useBitfield(0),
+  :blockLength(bitfieldMan.blockLength),
+   totalLength(bitfieldMan.totalLength),
+   bitfieldLength(bitfieldMan.bitfieldLength),
+   blocks(bitfieldMan.blocks),
+   filterEnabled(bitfieldMan.filterEnabled),
+   bitfield(new unsigned char[bitfieldLength]),
+   useBitfield(new unsigned char[bitfieldLength]),
    filterBitfield(0),
-   bitfieldLength(0),
-   blocks(0),
-   filterEnabled(false),
+   randomizer(bitfieldMan.randomizer),
    cachedNumMissingBlock(0),
    cachedNumFilteredBlock(0),
    cachedCompletedLength(0),
    cachedFilteredComletedLength(0),
    cachedFilteredTotalLength(0)
 {
-  blockLength = bitfieldMan.blockLength;
-  totalLength = bitfieldMan.totalLength;
-  blocks = bitfieldMan.blocks;
-  bitfieldLength = bitfieldMan.bitfieldLength;
-  bitfield = new unsigned char[bitfieldLength];
-  useBitfield = new unsigned char[bitfieldLength];
   memcpy(bitfield, bitfieldMan.bitfield, bitfieldLength);
   memcpy(useBitfield, bitfieldMan.useBitfield, bitfieldLength);
-  filterEnabled = bitfieldMan.filterEnabled;
-  if(filterBitfield) {
+  if(filterEnabled) {
     filterBitfield = new unsigned char[bitfieldLength];
     memcpy(filterBitfield, bitfieldMan.filterBitfield, bitfieldLength);
-  } else {
-    filterBitfield = 0;
   }
-  this->randomizer = bitfieldMan.randomizer;
   updateCache();
 }
 
@@ -142,16 +133,6 @@ BitfieldMan::~BitfieldMan() {
   delete [] filterBitfield;
 }
 
-size_t BitfieldMan::getBlockLength() const
-{
-  return blockLength;
-}
-
-size_t BitfieldMan::getLastBlockLength() const
-{
-  return totalLength-blockLength*(blocks-1);
-}
-
 size_t BitfieldMan::getBlockLength(size_t index) const
 {
   if(index == blocks-1) {
@@ -318,9 +299,10 @@ bool BitfieldMan::getMissingUnusedIndex(size_t& index) const
   }
 }
 
-size_t BitfieldMan::getStartIndex(size_t index) const {
-  while(index < blocks && (isUseBitSet(index) || isBitSet(index))) {
-    index++;
+template<typename Array>
+static size_t getStartIndex(size_t index, const Array& bitfield, size_t blocks) {
+  while(index < blocks && bitfield::test(bitfield, blocks, index)) {
+    ++index;
   }
   if(blocks <= index) {
     return blocks;
@@ -329,24 +311,33 @@ size_t BitfieldMan::getStartIndex(size_t index) const {
   }
 }
 
-size_t BitfieldMan::getEndIndex(size_t index) const {
-  while(index < blocks && (!isUseBitSet(index) && !isBitSet(index))) {
-    index++;
+template<typename Array>
+static size_t getEndIndex(size_t index, const Array& bitfield, size_t blocks) {
+  while(index < blocks && !bitfield::test(bitfield, blocks, index)) {
+    ++index;
   }
   return index;
 }
 
-bool BitfieldMan::getSparseMissingUnusedIndex(size_t& index) const {
-  Range maxRange;
-  Range currentRange;
+template<typename Array>
+static bool getSparseMissingUnusedIndex
+(size_t& index,
+ const Array& bitfield,
+ const unsigned char* useBitfield,
+ size_t blocks)
+{
+  BitfieldMan::Range maxRange;
+  BitfieldMan::Range currentRange;
   {
     size_t nextIndex = 0;
     while(nextIndex < blocks) {
-      currentRange.startIndex = getStartIndex(nextIndex);
+      currentRange.startIndex =
+	getStartIndex(nextIndex, bitfield, blocks);
       if(currentRange.startIndex == blocks) {
 	break;
       }
-      currentRange.endIndex = getEndIndex(currentRange.startIndex);
+      currentRange.endIndex =
+	getEndIndex(currentRange.startIndex, bitfield, blocks);
       if(maxRange < currentRange) {
 	maxRange = currentRange;
       }
@@ -356,7 +347,7 @@ bool BitfieldMan::getSparseMissingUnusedIndex(size_t& index) const {
   if(maxRange.getSize()) {
     if(maxRange.startIndex == 0) {
       index = 0;
-    } else if(isUseBitSet(maxRange.startIndex-1)) {
+    } else if(bitfield::test(useBitfield, blocks, maxRange.startIndex-1)) {
       index = maxRange.getMidIndex();
     } else {
       index = maxRange.startIndex;
@@ -367,6 +358,22 @@ bool BitfieldMan::getSparseMissingUnusedIndex(size_t& index) const {
   }
 }
 
+bool BitfieldMan::getSparseMissingUnusedIndex
+(size_t& index,
+ const unsigned char* ignoreBitfield,
+ size_t ignoreBitfieldLength) const
+{
+  if(filterEnabled) {
+    return aria2::getSparseMissingUnusedIndex
+      (index, array(ignoreBitfield)|~array(filterBitfield)|array(bitfield)|array(useBitfield),
+       useBitfield, blocks);
+  } else {
+    return aria2::getSparseMissingUnusedIndex
+      (index, array(ignoreBitfield)|array(bitfield)|array(useBitfield),
+       useBitfield, blocks);
+  }
+}
+
 template<typename Array>
 static bool copyBitfield(unsigned char* dst, const Array& src, size_t blocks)
 {
@@ -452,14 +459,6 @@ size_t BitfieldMan::countMissingBlockNow() const {
   }
 }
 
-size_t BitfieldMan::countFilteredBlock() const {
-  return cachedNumFilteredBlock;
-}
-
-size_t BitfieldMan::countBlock() const {
-  return blocks;
-}
-
 size_t BitfieldMan::countFilteredBlockNow() const {
   if(filterEnabled) {
     return bitfield::countSetBit(filterBitfield, blocks);
@@ -468,11 +467,6 @@ size_t BitfieldMan::countFilteredBlockNow() const {
   }
 }
 
-size_t BitfieldMan::getMaxIndex() const
-{
-  return blocks-1;
-}
-
 bool BitfieldMan::setBitInternal(unsigned char* bitfield, size_t index, bool on) {
   if(blocks <= index) { return false; }
   unsigned char mask = 128 >> index%8;
@@ -517,22 +511,37 @@ bool BitfieldMan::isFilteredAllBitSet() const {
   }
 }
 
-bool BitfieldMan::isAllBitSet() const {
-  if(bitfieldLength == 0) {
+static bool testAllBitSet
+(const unsigned char* bitfield, size_t length, size_t blocks)
+{
+  if(length == 0) {
     return true;
   }
-  for(size_t i = 0; i < bitfieldLength-1; ++i) {
+  for(size_t i = 0; i < length-1; ++i) {
     if(bitfield[i] != 0xff) {
       return false;
     }
   }
   unsigned char b = ~((128 >> (blocks-1)%8)-1);
-  if(bitfield[bitfieldLength-1] != b) {
+  if(bitfield[length-1] != b) {
     return false;
   }
   return true;
 }
 
+bool BitfieldMan::isAllBitSet() const
+{
+  return testAllBitSet(bitfield, bitfieldLength, blocks);
+}
+
+bool BitfieldMan::isAllFilterBitSet() const
+{
+  if(!filterBitfield) {
+    return false;
+  }
+  return testAllBitSet(filterBitfield, bitfieldLength, blocks);
+}
+
 bool BitfieldMan::isBitSet(size_t index) const
 {
   return bitfield::test(bitfield, blocks, index);
@@ -552,16 +561,6 @@ void BitfieldMan::setBitfield(const unsigned char* bitfield, size_t bitfieldLeng
   updateCache();
 }
 
-const unsigned char* BitfieldMan::getBitfield() const
-{
-  return bitfield;
-}
-
-size_t BitfieldMan::getBitfieldLength() const
-{
-  return bitfieldLength;
-}
-
 void BitfieldMan::clearAllBit() {
   memset(this->bitfield, 0, this->bitfieldLength);
   updateCache();
@@ -589,11 +588,16 @@ bool BitfieldMan::setFilterBit(size_t index) {
   return setBitInternal(filterBitfield, index, true);
 }
 
-void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
+void BitfieldMan::ensureFilterBitfield()
+{
   if(!filterBitfield) {
     filterBitfield = new unsigned char[bitfieldLength];
     memset(filterBitfield, 0, bitfieldLength);
   }
+}
+
+void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
+  ensureFilterBitfield();
   if(length > 0) {
     size_t startBlock = offset/blockLength;
     size_t endBlock = (offset+length-1)/blockLength;
@@ -604,7 +608,39 @@ void BitfieldMan::addFilter(uint64_t offset, uint64_t length) {
   updateCache();
 }
 
+void BitfieldMan::removeFilter(uint64_t offset, uint64_t length) {
+  ensureFilterBitfield();
+  if(length > 0) {
+    size_t startBlock = offset/blockLength;
+    size_t endBlock = (offset+length-1)/blockLength;
+    for(size_t i = startBlock; i <= endBlock && i < blocks; i++) {
+      setBitInternal(filterBitfield, i, false);
+    }
+  }
+  updateCache();
+}
+
+void BitfieldMan::addNotFilter(uint64_t offset, uint64_t length)
+{
+  ensureFilterBitfield();
+  if(length > 0 && blocks > 0) {
+    size_t startBlock = offset/blockLength;
+    if(blocks <= startBlock) {
+      startBlock = blocks;
+    }
+    size_t endBlock = (offset+length-1)/blockLength;
+    for(size_t i = 0; i < startBlock; ++i) {
+      setFilterBit(i);
+    }
+    for(size_t i = endBlock+1; i < blocks; ++i) {
+      setFilterBit(i);
+    }
+  }
+  updateCache();
+}
+
 void BitfieldMan::enableFilter() {
+  ensureFilterBitfield();
   filterEnabled = true;
   updateCache();
 }
@@ -623,14 +659,6 @@ void BitfieldMan::clearFilter() {
   updateCache();
 }
 
-bool BitfieldMan::isFilterEnabled() const {
-  return filterEnabled;
-}
-
-uint64_t BitfieldMan::getFilteredTotalLength() const {
-  return cachedFilteredTotalLength;
-}
-
 uint64_t BitfieldMan::getFilteredTotalLengthNow() const {
   if(!filterBitfield) {
     return 0;
@@ -673,18 +701,10 @@ uint64_t BitfieldMan::getCompletedLength(bool useFilter) const {
   return completedLength;
 }
 
-uint64_t BitfieldMan::getCompletedLength() const {
-  return cachedCompletedLength;
-}
-
 uint64_t BitfieldMan::getCompletedLengthNow() const {
   return getCompletedLength(false);
 }
 
-uint64_t BitfieldMan::getFilteredCompletedLength() const {
-  return cachedFilteredComletedLength;
-}
-
 uint64_t BitfieldMan::getFilteredCompletedLengthNow() const {
   return getCompletedLength(true);
 }
@@ -765,9 +785,4 @@ void BitfieldMan::setRandomizer(const SharedHandle<Randomizer>& randomizer)
   this->randomizer = randomizer;
 }
 
-SharedHandle<Randomizer> BitfieldMan::getRandomizer() const
-{
-  return randomizer;
-}
-
 } // namespace aria2
