@@ -54,7 +54,7 @@
 #include "DHTNode.h"
 #include "Peer.h"
 #include "Piece.h"
-#include "BtContext.h"
+#include "DownloadContext.h"
 #include "PieceStorage.h"
 #include "PeerStorage.h"
 #include "BtRuntime.h"
@@ -68,13 +68,15 @@
 #include "StringFormat.h"
 #include "RequestGroup.h"
 #include "RequestGroupMan.h"
+#include "bittorrent_helper.h"
 
 namespace aria2 {
 
 DefaultBtInteractive::DefaultBtInteractive
-(const SharedHandle<BtContext>& btContext, const SharedHandle<Peer>& peer)
+(const SharedHandle<DownloadContext>& downloadContext,
+ const SharedHandle<Peer>& peer)
   :
-  _btContext(btContext),
+  _downloadContext(downloadContext),
   peer(peer),
   logger(LogFactory::getInstance()),
   allowedFastSetSize(10),
@@ -88,8 +90,8 @@ DefaultBtInteractive::~DefaultBtInteractive() {}
 
 void DefaultBtInteractive::initiateHandshake() {
   SharedHandle<BtMessage> message =
-    messageFactory->createHandshakeMessage(_btContext->getInfoHash(),
-					   _btContext->getPeerId());
+    messageFactory->createHandshakeMessage
+    (bittorrent::getInfoHash(_downloadContext), bittorrent::getStaticPeerId());
   dispatcher->addMessageToQueue(message);
   dispatcher->sendMessages();
 }
@@ -100,7 +102,7 @@ BtMessageHandle DefaultBtInteractive::receiveHandshake(bool quickReply) {
   if(message.isNull()) {
     return SharedHandle<BtMessage>();
   }
-  if(memcmp(message->getPeerId(), _btContext->getPeerId(),
+  if(memcmp(message->getPeerId(), bittorrent::getStaticPeerId(),
 	    PEER_ID_LENGTH) == 0) {
     throw DL_ABORT_EX
       (StringFormat
@@ -187,10 +189,13 @@ void DefaultBtInteractive::addBitfieldMessageToQueue() {
 
 void DefaultBtInteractive::addAllowedFastMessageToQueue() {
   if(peer->isFastExtensionEnabled()) {
-    std::deque<size_t> fastSet;
-    _btContext->computeFastSet(fastSet, peer->ipaddr, allowedFastSetSize);
-    for(std::deque<size_t>::const_iterator itr = fastSet.begin();
-	itr != fastSet.end(); itr++) {
+    std::vector<size_t> fastSet;
+    bittorrent::computeFastSet(fastSet, peer->ipaddr,
+			       _downloadContext->getNumPieces(),
+			       bittorrent::getInfoHash(_downloadContext),
+			       allowedFastSetSize);
+    for(std::vector<size_t>::const_iterator itr = fastSet.begin();
+	itr != fastSet.end(); ++itr) {
       dispatcher->addMessageToQueue
 	(messageFactory->createAllowedFastMessage(*itr));
     }
@@ -221,7 +226,7 @@ void DefaultBtInteractive::checkHave() {
     }
   } else {
     for(std::deque<size_t>::iterator itr = indexes.begin();
-	itr != indexes.end(); itr++) {
+	itr != indexes.end(); ++itr) {
       dispatcher->addMessageToQueue(messageFactory->createHaveMessage(*itr));
     }
   }
@@ -237,9 +242,9 @@ void DefaultBtInteractive::sendKeepAlive() {
 
 size_t DefaultBtInteractive::receiveMessages() {
   size_t msgcount = 0;
-  for(int i = 0; i < 50; i++) {
+  for(int i = 0; i < 50; ++i) {
     if(_requestGroupMan->doesOverallDownloadSpeedExceed() ||
-       _btContext->getOwnerRequestGroup()->doesDownloadSpeedExceed()) {
+       _downloadContext->getOwnerRequestGroup()->doesDownloadSpeedExceed()) {
       break;
     }
     BtMessageHandle message = btMessageReceiver->receiveMessage();
@@ -382,7 +387,7 @@ void DefaultBtInteractive::checkActiveInteraction()
   // To allow aria2 to accept mutially interested peer, disconnect unintersted
   // peer.
   {
-    time_t interval = 30;
+    const time_t interval = 30;
     if(!peer->amInterested() && !peer->peerInterested() &&
        inactiveCheckPoint.elapsed(interval)) {
       // TODO change the message
@@ -395,7 +400,7 @@ void DefaultBtInteractive::checkActiveInteraction()
   // mutual download progress are completely waste of resources, those peers
   // are disconnected in a certain time period.
   {
-    time_t interval = 2*60;
+    const time_t interval = 2*60;
     if(inactiveCheckPoint.elapsed(interval)) {
       throw DL_ABORT_EX
 	(StringFormat(EX_DROP_INACTIVE_CONNECTION, interval).str());
