@@ -37,14 +37,16 @@
 
 #include "common.h"
 
+#include <cassert>
 #include <string>
 #include <deque>
 
 #include "SharedHandle.h"
+#include "Request.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
-class Request;
 class Segment;
 class Range;
 class Option;
@@ -59,9 +61,9 @@ private:
 
   SharedHandle<Request> request;
 
-  SharedHandle<Segment> segment;
+  SharedHandle<FileEntry> _fileEntry;
 
-  uint64_t entityLength;
+  SharedHandle<Segment> segment;
 
   bool _contentEncodingEnabled;
 
@@ -75,6 +77,8 @@ private:
 
   SharedHandle<AuthConfigFactory> _authConfigFactory;
 
+  const Option* _option;
+
   SharedHandle<AuthConfig> _authConfig;
 
   SharedHandle<Request> _proxyRequest;
@@ -85,42 +89,65 @@ private:
 public:
   HttpRequest();
 
-  SharedHandle<Segment> getSegment() const;
+  const SharedHandle<Segment>& getSegment() const
+  {
+    return segment;
+  }
 
   void setSegment(const SharedHandle<Segment>& segment);
 
   void setRequest(const SharedHandle<Request>& request);
 
-  /**
-   * entityLength is used in isRangeSatisfied() method.
-   */
-  void setEntityLength(uint64_t entityLength)
-  {
-    this->entityLength = entityLength;
-  }
-
   uint64_t getEntityLength() const
   {
-    return entityLength;
+    assert(!_fileEntry.isNull());
+    return _fileEntry->getLength();
   }
 
-  const std::string& getHost() const;
+  const std::string& getHost() const
+  {
+    return request->getHost();
+  }
 
-  uint16_t getPort() const;
+  uint16_t getPort() const
+  {
+    return request->getPort();
+  }
 
-  const std::string& getMethod() const;
+  const std::string& getMethod() const
+  {
+    return request->getMethod();
+  }
 
-  const std::string& getProtocol() const;
+  const std::string& getProtocol() const
+  {
+    return request->getProtocol();
+  }
 
-  const std::string& getCurrentURI() const;
+  const std::string& getCurrentURI() const
+  {
+    return request->getCurrentUrl();
+  }
   
-  const std::string& getDir() const;
+  const std::string& getDir() const
+  {
+    return request->getDir();
+  }
 
-  const std::string& getFile() const;
+  const std::string& getFile() const
+  {
+    return request->getFile();
+  }
 
-  const std::string& getQuery() const;
+  const std::string& getQuery() const
+  {
+    return request->getQuery();
+  }
 
-  const std::string& getPreviousURI() const;
+  const std::string& getPreviousURI() const
+  {
+    return request->getPreviousUrl();
+  }
 
   SharedHandle<Range> getRange() const;
 
@@ -130,7 +157,10 @@ public:
    */
   bool isRangeSatisfied(const SharedHandle<Range>& range) const;
 
-  SharedHandle<Request> getRequest() const;
+  const SharedHandle<Request>& getRequest() const
+  {
+    return request;
+  }
 
   off_t getStartByte() const;
 
@@ -173,9 +203,13 @@ public:
 
   void setCookieStorage(const SharedHandle<CookieStorage>& cookieStorage);
 
-  SharedHandle<CookieStorage> getCookieStorage() const;
+  const SharedHandle<CookieStorage>& getCookieStorage() const
+  {
+    return _cookieStorage;
+  }
 
-  void setAuthConfigFactory(const SharedHandle<AuthConfigFactory>& factory);
+  void setAuthConfigFactory
+  (const SharedHandle<AuthConfigFactory>& factory, const Option* option);
 
   /*
    * To use proxy, pass proxy string to Request::setUrl() and set it this
@@ -196,6 +230,16 @@ public:
   // Returns AuthConfig used in the last invocation of
   // createRequest().
   const SharedHandle<AuthConfig>& getAuthConfig() const;
+
+  void setFileEntry(const SharedHandle<FileEntry>& fileEntry)
+  {
+    _fileEntry = fileEntry;
+  }
+
+  const SharedHandle<FileEntry>& getFileEntry() const
+  {
+    return _fileEntry;
+  }
 };
 
 typedef SharedHandle<HttpRequest> HttpRequestHandle;
