@@ -53,18 +53,20 @@
 #include "CookieStorage.h"
 #include "AuthConfigFactory.h"
 #include "AuthConfig.h"
+#include "DownloadContext.h"
 
 namespace aria2 {
 
 HttpSkipResponseCommand::HttpSkipResponseCommand
 (int cuid,
  const SharedHandle<Request>& req,
+ const SharedHandle<FileEntry>& fileEntry,
  RequestGroup* requestGroup,
  const SharedHandle<HttpConnection>& httpConnection,
  const SharedHandle<HttpResponse>& httpResponse,
  DownloadEngine* e,
  const SharedHandle<SocketCore>& s):
-  AbstractCommand(cuid, req, requestGroup, e, s),
+  AbstractCommand(cuid, req, fileEntry, requestGroup, e, s),
   _httpConnection(httpConnection),
   _httpResponse(httpResponse),
   _totalLength(_httpResponse->getEntityLength()),
@@ -109,7 +111,7 @@ bool HttpSkipResponseCommand::executeInternal()
     }
     if(_totalLength != 0 && bufSize == 0 &&
        !socket->wantRead() && !socket->wantWrite()) {
-      throw DlRetryEx(EX_GOT_EOF);
+      throw DL_RETRY_EX(EX_GOT_EOF);
     }
   } catch(RecoverableException& e) {
     logger->debug(EX_EXCEPTION_CAUGHT, e);
@@ -151,7 +153,7 @@ bool HttpSkipResponseCommand::processResponse()
     unsigned int rnum =
       _httpResponse->getHttpRequest()->getRequest()->getRedirectCount();
     if(rnum >= Request::MAX_REDIRECT) {
-      throw DlAbortEx(StringFormat("Too many redirects: count=%u", rnum).str());
+      throw DL_ABORT_EX(StringFormat("Too many redirects: count=%u", rnum).str());
     }
     _httpResponse->processRedirect();
     return prepareForRetry(0);
@@ -159,19 +161,19 @@ bool HttpSkipResponseCommand::processResponse()
     return prepareForRetry(_httpResponse->getRetryAfter());
   } else if(_httpResponse->getResponseStatus() >= HttpHeader::S400) {
     if(_httpResponse->getResponseStatus() == HttpHeader::S401) {
-      if(e->option->getAsBool(PREF_HTTP_AUTH_CHALLENGE) &&
+      if(getOption()->getAsBool(PREF_HTTP_AUTH_CHALLENGE) &&
 	 !_httpResponse->getHttpRequest()->authenticationUsed() &&
 	 e->getAuthConfigFactory()->activateBasicCred
-	 (req->getHost(), req->getDir())) {
+	 (req->getHost(), req->getDir(), getOption().get())) {
 	return prepareForRetry(0);
       } else {
-	throw DlAbortEx(EX_AUTH_FAILED);
+	throw DL_ABORT_EX(EX_AUTH_FAILED);
       }
     }else if(_httpResponse->getResponseStatus() == HttpHeader::S404) {
-      throw DlAbortEx(MSG_RESOURCE_NOT_FOUND,
-		      DownloadResult::RESOURCE_NOT_FOUND);
+      throw DL_ABORT_EX2(MSG_RESOURCE_NOT_FOUND,
+			 downloadresultcode::RESOURCE_NOT_FOUND);
     } else {
-      throw DlAbortEx(StringFormat(EX_BAD_STATUS, Util::parseUInt(_httpResponse->getResponseStatus())).str());
+      throw DL_ABORT_EX(StringFormat(EX_BAD_STATUS, Util::parseUInt(_httpResponse->getResponseStatus())).str());
     }
   } else {
     return prepareForRetry(0);
