@@ -41,6 +41,7 @@
 #include "Util.h"
 #include "help_tags.h"
 #include "StringFormat.h"
+#include "File.h"
 
 namespace aria2 {
 
@@ -141,7 +142,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new DefaultOptionHandler
 				   (PREF_DIR,
 				    TEXT_DIR,
-				    ".",
+				    File::getCurrentDir(),
 				    A2STR::NIL,
 				    OptionHandler::REQ_ARG,
 				    'd'));
@@ -511,15 +512,6 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
   }
-  {
-    SharedHandle<OptionHandler> op(new BooleanOptionHandler
-				   (PREF_RESET_URI,
-				    NO_DESCRIPTION,
-				    V_FALSE,
-				    OptionHandler::OPT_ARG));
-    op->hide();
-    handlers.push_back(op);
-  }
   {
     SharedHandle<OptionHandler> op(new NumberOptionHandler
 				   (PREF_RETRY_WAIT,
@@ -757,7 +749,7 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     SharedHandle<OptionHandler> op(new BooleanOptionHandler
 				   (PREF_USE_HEAD,
 				    TEXT_USE_HEAD,
-				    V_TRUE,
+				    V_FALSE,
 				    OptionHandler::OPT_ARG));
     op->addTag(TAG_HTTP);
     handlers.push_back(op);
@@ -996,6 +988,15 @@ OptionHandlers OptionHandlerFactory::createOptionHandlers()
     op->addTag(TAG_BITTORRENT);
     handlers.push_back(op);
   }
+  {
+    SharedHandle<OptionHandler> op(new NumberOptionHandler
+				   (PREF_BT_STOP_TIMEOUT,
+				    TEXT_BT_STOP_TIMEOUT,
+				    "0",
+				    0));
+    op->addTag(TAG_BITTORRENT);
+    handlers.push_back(op);
+  }
   {
     SharedHandle<NumberOptionHandler> op(new NumberOptionHandler
 					 (PREF_BT_TIMEOUT,
