@@ -40,7 +40,6 @@
 namespace aria2 {
 
 class RequestGroup;
-class BtContext;
 class BtRuntime;
 class PeerStorage;
 class PieceStorage;
@@ -49,8 +48,6 @@ class PeerInitiateConnectionCommand : public PeerAbstractCommand {
 private:
   RequestGroup* _requestGroup;
 
-  SharedHandle<BtContext> _btContext;
-
   SharedHandle<BtRuntime> _btRuntime;
 
   SharedHandle<PeerStorage> _peerStorage;
@@ -69,7 +66,6 @@ public:
 				RequestGroup* requestGroup,
 				const SharedHandle<Peer>& peer,
 				DownloadEngine* e,
-				const SharedHandle<BtContext>& btContext,
 				const SharedHandle<BtRuntime>& btRuntime,
 				bool mseHandshakeEnabled = true);
 
