@@ -44,8 +44,7 @@
 #include "TransferStat.h"
 #include "TimeA2.h"
 #include "Request.h"
-#include "DownloadResult.h"
-#include "URIResult.h"
+#include "DownloadResultCode.h"
 
 namespace aria2 {
 
@@ -66,23 +65,28 @@ class Logger;
 class RequestGroup;
 class CheckIntegrityEntry;
 class DownloadResult;
-class ServerHost;
 class URISelector;
+class URIResult;
 #ifdef ENABLE_BITTORRENT
 class BtRuntime;
 class PeerStorage;
 #endif // ENABLE_BITTORRENT
 
 class RequestGroup {
+public:
+  enum HaltReason {
+    NONE,
+    SHUTDOWN_SIGNAL,
+    USER_REQUEST
+  };
 private:
   static int32_t _gidCounter;
 
   int32_t _gid;
 
-  std::deque<std::string> _uris;
-  std::deque<std::string> _spentUris;
+  SharedHandle<Option> _option;
 
-  unsigned int _numConcurrentCommand;
+  size_t _numConcurrentCommand;
 
   /**
    * This is the number of connections used in streaming protocol(http/ftp)
@@ -104,8 +108,6 @@ private:
 
   SharedHandle<Dependency> _dependency;
 
-  std::deque<SharedHandle<ServerHost> > _serverHosts;
-
   bool _fileAllocationEnabled;
 
   bool _preLocalFileCheckEnabled;
@@ -114,18 +116,12 @@ private:
 
   bool _forceHaltRequested;
 
-  // URIResult is stored in the ascending order of the time when its result is
-  // available.
-  std::deque<URIResult> _uriResults;
-
-  bool _singleHostMultiConnectionEnabled;
+  HaltReason _haltReason;
 
   std::deque<SharedHandle<PreDownloadHandler> > _preDownloadHandlers;
 
   std::deque<SharedHandle<PostDownloadHandler> > _postDownloadHandlers;
 
-  std::deque<std::string> _acceptFeatures;
-
   std::deque<std::string> _acceptTypes;
 
   SharedHandle<URISelector> _uriSelector;
@@ -137,9 +133,6 @@ private:
   // Timeout used for HTTP/FTP downloads.
   time_t _timeout;
 
-  // How many times HTTP/FTP download should retry.
-  unsigned int _maxTries;
-
 #ifdef ENABLE_BITTORRENT
   WeakHandle<BtRuntime> _btRuntime;
 
@@ -154,87 +147,64 @@ private:
 
   unsigned int _maxUploadSpeedLimit;
 
-  const Option* _option;
+  SharedHandle<URIResult> _lastUriResult;
 
   Logger* _logger;
 
   void validateFilename(const std::string& expectedFilename,
 			const std::string& actualFilename) const;
 
-  void validateTotalLength(uint64_t expectedTotalLength,
-			   uint64_t actualTotalLength) const;
-
   void initializePreDownloadHandler();
 
   void initializePostDownloadHandler();
 
   bool tryAutoFileRenaming();
 
-  // Returns the result code of this RequestGroup.
-  // If the download finished, then returns DownloadResult::FINISHED.
-  // If the download didn't finish and error result is available in _uriResults,
-  // then last result code is returned.
-  // Otherwise returns DownloadResult::UNKNOWN_ERROR.
-  DownloadResult::RESULT downloadResult() const;
+  // Returns the result code of this RequestGroup.  If the download
+  // finished, then returns downloadresultcode::FINISHED.  If the
+  // download didn't finish and error result is available in
+  // _uriResults, then last result code is returned.  Otherwise
+  // returns downloadresultcode::UNKNOWN_ERROR.
+  downloadresultcode::RESULT downloadResult() const;
 public:
-  RequestGroup(const Option* option, const std::deque<std::string>& uris);
+  RequestGroup(const SharedHandle<Option>& option);
 
   ~RequestGroup();
   /**
    * Reinitializes SegmentMan based on current property values and
    * returns new one.
    */
-  SharedHandle<SegmentMan> initSegmentMan();
+  const SharedHandle<SegmentMan>& initSegmentMan();
 
-  SharedHandle<SegmentMan> getSegmentMan() const;
+  const SharedHandle<SegmentMan>& getSegmentMan() const
+  {
+    return _segmentMan;
+  }
 
   // Returns first bootstrap commands to initiate a download.
   // If this is HTTP/FTP download and file size is unknown, only 1 command
-  // (usually, HttpInitiateConnection or FtpInitiateConnection) will be created
-  // with its Request object having Requet::METHOD_HEAD in its method.
-  // This behavior can be changed by providing 3rd argument.
-  // The method has effect only for using HTTP request including FTP via HTTP
-  // proxy.
+  // (usually, HttpInitiateConnection or FtpInitiateConnection) will be created.
   void createInitialCommand(std::deque<Command*>& commands,
-			    DownloadEngine* e,
-			    const std::string& method = Request::METHOD_HEAD);
+			    DownloadEngine* e);
 
   void createNextCommandWithAdj(std::deque<Command*>& commands,
 				DownloadEngine* e, int numAdj);
 
   void createNextCommand(std::deque<Command*>& commands,
-			 DownloadEngine* e, unsigned int numCommand,
-			 const std::string& method = Request::METHOD_GET);
+			 DownloadEngine* e, unsigned int numCommand);
   
-  void addURI(const std::string& uri)
-  {
-    _uris.push_back(uri);
-  }
-
   bool downloadFinished() const;
 
   bool allDownloadFinished() const;
 
   void closeFile();
 
-  std::string getFilePath() const;
+  std::string getFirstFilePath() const;
 
   uint64_t getTotalLength() const;
 
   uint64_t getCompletedLength() const;
 
-  const std::deque<std::string>& getRemainingUris() const
-  {
-    return _uris;
-  }
-
-  const std::deque<std::string>& getSpentUris() const
-  {
-    return _spentUris;
-  }
-
-  void getURIs(std::deque<std::string>& uris) const;
-
   /**
    * Compares expected filename with specified actualFilename.
    * The expected filename refers to FileEntry::getBasename() of the first
@@ -242,6 +212,9 @@ public:
    */
   void validateFilename(const std::string& actualFilename) const;
 
+  void validateTotalLength(uint64_t expectedTotalLength,
+			   uint64_t actualTotalLength) const;
+
   void validateTotalLength(uint64_t actualTotalLength) const;
 
   void setSegmentManFactory(const SharedHandle<SegmentManFactory>& segmentManFactory);
@@ -251,7 +224,10 @@ public:
     _numConcurrentCommand = num;
   }
 
-  unsigned int getNumConcurrentCommand() const;
+  unsigned int getNumConcurrentCommand() const
+  {
+    return _numConcurrentCommand;
+  }
 
   int32_t getGID() const
   {
@@ -260,15 +236,27 @@ public:
 
   TransferStat calculateStat();
 
-  SharedHandle<DownloadContext> getDownloadContext() const;
+  const SharedHandle<DownloadContext>& getDownloadContext() const
+  {
+    return _downloadContext;
+  }
 
-  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext);
+  void setDownloadContext(const SharedHandle<DownloadContext>& downloadContext)
+  {
+    _downloadContext = downloadContext;
+  }
 
-  SharedHandle<PieceStorage> getPieceStorage() const;
+  const SharedHandle<PieceStorage>& getPieceStorage() const
+  {
+    return _pieceStorage;
+  }
 
   void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
 
-  SharedHandle<BtProgressInfoFile> getProgressInfoFile() const;
+  const SharedHandle<BtProgressInfoFile>& getProgressInfoFile() const
+  {
+    return _progressInfoFile;
+  }
 
   void setProgressInfoFile(const SharedHandle<BtProgressInfoFile>& progressInfoFile);
 
@@ -276,6 +264,9 @@ public:
 
   void decreaseStreamConnection();
 
+  // Returns the number of connections used in HTTP(S)/FTP.
+  unsigned int getNumStreamConnection() { return _numStreamConnection; }
+
   unsigned int getNumConnection() const;
 
   void increaseNumCommand();
@@ -290,7 +281,10 @@ public:
   // TODO is it better to move the following 2 methods to SingleFileDownloadContext?
   void setDiskWriterFactory(const SharedHandle<DiskWriterFactory>& diskWriterFactory);
 
-  SharedHandle<DiskWriterFactory> getDiskWriterFactory() const;
+  const SharedHandle<DiskWriterFactory>& getDiskWriterFactory() const
+  {
+    return _diskWriterFactory;
+  }
 
   void setFileAllocationEnabled(bool f)
   {
@@ -319,9 +313,9 @@ public:
     return _preLocalFileCheckEnabled;
   }
 
-  void setHaltRequested(bool f);
+  void setHaltRequested(bool f, HaltReason = SHUTDOWN_SIGNAL);
 
-  void setForceHaltRequested(bool f);
+  void setForceHaltRequested(bool f, HaltReason = SHUTDOWN_SIGNAL);
 
   bool isHaltRequested() const
   {
@@ -333,14 +327,6 @@ public:
     return _forceHaltRequested;
   }
 
-  void addURIResult(std::string uri, DownloadResult::RESULT result);
-
-  const std::deque<URIResult>& getURIResults() const;
-
-  // Extracts URIResult whose _result is r and stores them into res.
-  // The extracted URIResults are removed from _uriResults.
-  void extractURIResult(std::deque<URIResult>& res, DownloadResult::RESULT r);
-
   void dependsOn(const SharedHandle<Dependency>& dep);
 
   bool isDependencyResolved();
@@ -375,49 +361,17 @@ public:
 
   SharedHandle<DownloadResult> createDownloadResult() const;
 
-  const Option* getOption() const
+  const SharedHandle<Option>& getOption() const
   {
     return _option;
   }
 
-  bool isSingleHostMultiConnectionEnabled() const
-  {
-    return _singleHostMultiConnectionEnabled;
-  }
-
-  void setSingleHostMultiConnectionEnabled(bool f)
-  {
-    _singleHostMultiConnectionEnabled = f;
-  }
-
-  /**
-   * Registers given ServerHost.
-   */
-  void registerServerHost(const SharedHandle<ServerHost>& serverHost);
-
-  /**
-   * Returns ServerHost whose cuid is given cuid. If it is not found, returns
-   * 0.
-   */
-  SharedHandle<ServerHost> searchServerHost(int32_t cuid) const;
-
-  SharedHandle<ServerHost> searchServerHost(const std::string& hostname) const;
-
-  void removeServerHost(int32_t cuid);
-  
-  void removeURIWhoseHostnameIs(const std::string& hostname);
-
-  void removeIdenticalURI(const std::string& uri);
-
   void reportDownloadFinished();
 
-  const std::deque<std::string>& getAcceptFeatures() const;
-
-  void addAcceptFeatureHeader(const std::string& feature);
-
-  void removeAcceptFeatureHeader(const std::string& feature);
-
-  const std::deque<std::string>& getAcceptTypes() const;
+  const std::deque<std::string>& getAcceptTypes() const
+  {
+    return _acceptTypes;
+  }
 
   void addAcceptType(const std::string& type);
 
@@ -427,6 +381,11 @@ public:
 
   void setURISelector(const SharedHandle<URISelector>& uriSelector);
 
+  const SharedHandle<URISelector>& getURISelector() const
+  {
+    return _uriSelector;
+  }
+
   void applyLastModifiedTimeToLocalFiles();
 
   void updateLastModifiedTime(const Time& time);
@@ -437,17 +396,17 @@ public:
   void markInMemoryDownload();
 
   // Returns inMemoryDownload flag.
-  bool inMemoryDownload() const;
-
-  void tuneDownloadCommand(DownloadCommand* command);
+  bool inMemoryDownload() const
+  {
+    return _inMemoryDownload;
+  }
 
   void setTimeout(time_t timeout);
 
-  time_t getTimeout() const;
-
-  void setMaxTries(unsigned int maxTries);
-
-  unsigned int getMaxTries() const;
+  time_t getTimeout() const
+  {
+    return _timeout;
+  }
 
   // Returns true if current download speed exceeds
   // _maxDownloadSpeedLimit.  Always returns false if
@@ -464,10 +423,24 @@ public:
     return _maxDownloadSpeedLimit;
   }
 
+  void setMaxDownloadSpeedLimit(unsigned int speed)
+  {
+    _maxDownloadSpeedLimit = speed;
+  }
+
   unsigned int getMaxUploadSpeedLimit() const
   {
     return _maxUploadSpeedLimit;
   }
+
+  void setMaxUploadSpeedLimit(unsigned int speed)
+  {
+    _maxUploadSpeedLimit = speed;
+  }
+
+  void setLastUriResult(std::string uri, downloadresultcode::RESULT result);
+
+  static void resetGIDCounter() { _gidCounter = 0; }
 };
 
 typedef SharedHandle<RequestGroup> RequestGroupHandle;
