@@ -80,13 +80,14 @@ RequestGroupMan::RequestGroupMan(const RequestGroups& requestGroups,
   _serverStatMan(new ServerStatMan()),
   _maxOverallDownloadSpeedLimit
   (option->getAsInt(PREF_MAX_OVERALL_DOWNLOAD_LIMIT)),
-  _maxOverallUploadSpeedLimit(option->getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT))
+  _maxOverallUploadSpeedLimit(option->getAsInt(PREF_MAX_OVERALL_UPLOAD_LIMIT)),
+  _xmlRpc(option->getAsBool(PREF_ENABLE_XML_RPC))
 {}
 
 bool RequestGroupMan::downloadFinished()
 {
 #ifdef ENABLE_XML_RPC
-  if(_option->getAsBool(PREF_ENABLE_XML_RPC)) {
+  if(_xmlRpc) {
     return false;
   }
 #endif // ENABLE_XML_RPC
@@ -197,6 +198,7 @@ static void executeHook(const std::string& command, int gid)
 {
   LogFactory::getInstance()->info("Executing user command: %s %d",
 				  command.c_str(), gid);
+#ifndef __MINGW32__
   pid_t cpid = fork();
   if(cpid == -1) {
     LogFactory::getInstance()->error("fork() failed."
@@ -206,6 +208,34 @@ static void executeHook(const std::string& command, int gid)
     perror(("Could not execute user command: "+command).c_str());
     _exit(1);
   }
+#else
+  PROCESS_INFORMATION pi;
+  STARTUPINFO si;
+
+  memset(&si, 0, sizeof (si));
+  si.cb = sizeof(STARTUPINFO);
+
+  memset(&pi, 0, sizeof (pi));
+
+  std::string cmdline = command;
+  strappend(cmdline, " ", Util::itos(gid));
+
+  DWORD rc = CreateProcess(
+    NULL,
+    (LPSTR)cmdline.c_str(),
+    NULL,
+    NULL,
+    true,
+    NULL,
+    NULL,
+    0,
+    &si,
+    &pi);
+
+  if(!rc)
+    LogFactory::getInstance()->error("CreateProcess() failed."
+				     " Cannot execute user command.");
+#endif 
 }
 
 static void executeStartHook
@@ -219,10 +249,10 @@ static void executeStartHook
 static void executeStopHook
 (const SharedHandle<DownloadResult>& result, const Option* option)
 {
-  if(result->result == DownloadResult::FINISHED &&
+  if(result->result == downloadresultcode::FINISHED &&
      !option->blank(PREF_ON_DOWNLOAD_COMPLETE)) {
     executeHook(option->get(PREF_ON_DOWNLOAD_COMPLETE), result->gid);
-  } else if(result->result != DownloadResult::IN_PROGRESS &&
+  } else if(result->result != downloadresultcode::IN_PROGRESS &&
 	    !option->blank(PREF_ON_DOWNLOAD_ERROR)) {
     executeHook(option->get(PREF_ON_DOWNLOAD_ERROR), result->gid);
   } else if(!option->blank(PREF_ON_DOWNLOAD_STOP)) {
@@ -244,7 +274,7 @@ private:
     if(!sig.isNull() && !sig->getBody().empty()) {
       // filename of signature file is the path to download file followed by
       // ".sig".
-      std::string signatureFile = group->getFilePath()+".sig";
+      std::string signatureFile = group->getFirstFilePath()+".sig";
       if(sig->save(signatureFile)) {
 	_logger->notice(MSG_SIGNATURE_SAVED, signatureFile.c_str());
       } else {
@@ -312,9 +342,10 @@ public:
       // Collect statistics during download in PeerStats and update/register
       // ServerStatMan
       if(!group->getSegmentMan().isNull()) {
+	bool singleConnection =
+	  group->getSegmentMan()->getPeerStats().size() == 1;
 	const std::deque<SharedHandle<PeerStat> >& peerStats =
-	  group->getSegmentMan()->getPeerStats();
-
+	  group->getSegmentMan()->getFastestPeerStats();
 	for(std::deque<SharedHandle<PeerStat> >::const_iterator i =
 	      peerStats.begin(); i != peerStats.end(); ++i) {
 	  if((*i)->getHostname().empty() || (*i)->getProtocol().empty()) {
@@ -328,7 +359,7 @@ public:
 						    (*i)->getProtocol());
           ss->increaseCounter();
 	  ss->updateDownloadSpeed(speed);
-          if(peerStats.size() == 1) {
+          if(singleConnection) {
             ss->updateSingleConnectionAvgSpeed(speed);
           }
           else {
@@ -363,10 +394,13 @@ void RequestGroupMan::removeStoppedGroup(DownloadEngine* e)
 		ProcessStoppedRequestGroup(e, _reservedGroups,
 					   _downloadResults));
 
-  _requestGroups.erase(std::remove_if(_requestGroups.begin(),
-				      _requestGroups.end(),
-				      FindStoppedRequestGroup()),
-		       _requestGroups.end());
+  std::deque<SharedHandle<RequestGroup> >::iterator i =
+    std::remove_if(_requestGroups.begin(),
+		   _requestGroups.end(),
+		   FindStoppedRequestGroup());
+  if(i != _requestGroups.end()) {
+    _requestGroups.erase(i, _requestGroups.end());
+  }
 
   size_t numRemoved = numPrev-_requestGroups.size();
   if(numRemoved > 0) {
@@ -394,13 +428,9 @@ void RequestGroupMan::configureRequestGroup
 
 static void createInitialCommand(const SharedHandle<RequestGroup>& requestGroup,
 				 std::deque<Command*>& commands,
-				 DownloadEngine* e,
-				 bool useHead)
+				 DownloadEngine* e)
 {
-  requestGroup->createInitialCommand(commands, e,
-				     useHead ?
-				     Request::METHOD_HEAD :
-				     Request::METHOD_GET);
+  requestGroup->createInitialCommand(commands, e);
 }
 
 void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
@@ -422,9 +452,7 @@ void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
       }
       configureRequestGroup(groupToAdd);
       Commands commands;
-      createInitialCommand(groupToAdd, commands, e,
-			   _option->getAsBool(PREF_USE_HEAD)||
-			   _option->getAsBool(PREF_DRY_RUN));
+      createInitialCommand(groupToAdd, commands, e);
       _requestGroups.push_back(groupToAdd);
       ++count;
       e->addCommand(commands);
@@ -435,7 +463,9 @@ void RequestGroupMan::fillRequestGroupFromReserver(DownloadEngine* e)
       _downloadResults.push_back(groupToAdd->createDownloadResult());
     }
   }
-  _reservedGroups.insert(_reservedGroups.begin(), temp.begin(), temp.end());
+  if(!temp.empty()) {
+    _reservedGroups.insert(_reservedGroups.begin(), temp.begin(), temp.end());
+  }
   if(count > 0) {
     e->setNoWait(true);
     _logger->debug("%d RequestGroup(s) added.", count);
@@ -450,8 +480,7 @@ void RequestGroupMan::getInitialCommands(std::deque<Command*>& commands,
     try {
       if((*itr)->isDependencyResolved()) {
 	configureRequestGroup(*itr);
-	createInitialCommand(*itr, commands, e,
-			     _option->getAsBool(PREF_USE_HEAD));
+	createInitialCommand(*itr, commands, e);
 	executeStartHook(*itr, e->option);
 	++itr;
       } else {
@@ -495,10 +524,10 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
   size_t finished = 0;
   size_t error = 0;
   size_t inprogress = 0;
-  DownloadResult::RESULT lastError = DownloadResult::FINISHED;
+  downloadresultcode::RESULT lastError = downloadresultcode::FINISHED;
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr = _downloadResults.begin();
       itr != _downloadResults.end(); ++itr) {
-    if((*itr)->result == DownloadResult::FINISHED) {
+    if((*itr)->result == downloadresultcode::FINISHED) {
       ++finished;
     } else {
       ++error;
@@ -508,7 +537,7 @@ RequestGroupMan::DownloadStat RequestGroupMan::getDownloadStat() const
   for(RequestGroups::const_iterator itr = _requestGroups.begin();
       itr != _requestGroups.end(); ++itr) {
     DownloadResultHandle result = (*itr)->createDownloadResult();
-    if(result->result == DownloadResult::FINISHED) {
+    if(result->result == downloadresultcode::FINISHED) {
       ++finished;
     } else {
       ++inprogress;
@@ -530,7 +559,7 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
   o << "\n"
     <<_("Download Results:") << "\n"
     << "gid|stat|avg speed  |path/URI" << "\n"
-    << "===+====+===========+==========================================================" << "\n";
+    << "===+====+===========+===========================================================" << "\n";
 
   int ok = 0;
   int err = 0;
@@ -539,10 +568,10 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr = _downloadResults.begin();
       itr != _downloadResults.end(); ++itr) {
     std::string status;
-    if((*itr)->result == DownloadResult::FINISHED) {
+    if((*itr)->result == downloadresultcode::FINISHED) {
       status = MARK_OK;
       ++ok;
-    } else if((*itr)->result == DownloadResult::IN_PROGRESS) {
+    } else if((*itr)->result == downloadresultcode::IN_PROGRESS) {
       status = MARK_INPR;
       ++inpr;
     } else {
@@ -555,7 +584,7 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
       itr != _requestGroups.end(); ++itr) {
     DownloadResultHandle result = (*itr)->createDownloadResult();
     std::string status;
-    if(result->result == DownloadResult::FINISHED) {
+    if(result->result == downloadresultcode::FINISHED) {
       status = MARK_OK;
       ++ok;
     } else {
@@ -587,54 +616,6 @@ void RequestGroupMan::showDownloadResults(std::ostream& o) const
   }
 }
 
-template<typename InputIterator>
-static SharedHandle<FileEntry> getFirstRequestedFileEntry
-(InputIterator first, InputIterator last)
-{
-  for(; first != last; ++first) {
-    if((*first)->isRequested()) {
-      return *first;
-    }
-  }
-  return SharedHandle<FileEntry>();
-}
-
-template<typename InputIterator>
-static size_t countRequestedFileEntry(InputIterator first, InputIterator last)
-{
-  size_t count = 0;
-  for(; first != last; ++first) {
-    if((*first)->isRequested()) {
-      ++count;
-    }
-  }
-  return count;
-}
-
-template<typename InputIterator>
-static void writeFilePath
-(InputIterator first, InputIterator last, std::ostream& o, bool memory)
-{
-  SharedHandle<FileEntry> e = getFirstRequestedFileEntry(first, last);
-  if(e.isNull()) {
-    o << "n/a";
-  } else {
-    if(e->getPath().empty()) {
-      o << "n/a";
-    } else {
-      if(memory) {
-	o << "[MEMORY]" << File(e->getPath()).getBasename();
-      } else {
-	o << e->getPath();
-      }
-    }
-    size_t count = countRequestedFileEntry(first, last);
-    if(count > 1) {
-      o << " (" << count-1 << "more)";
-    }
-  }
-}
-
 std::string RequestGroupMan::formatDownloadResult(const std::string& status, const DownloadResultHandle& downloadResult) const
 {
   std::stringstream o;
@@ -649,18 +630,10 @@ std::string RequestGroupMan::formatDownloadResult(const std::string& status, con
     o << "n/a";
   }
   o << "|";
-  const std::deque<SharedHandle<FileEntry> >& fileEntries =
+  const std::vector<SharedHandle<FileEntry> >& fileEntries =
     downloadResult->fileEntries;
-  if(downloadResult->result == DownloadResult::FINISHED ||
-     downloadResult->numUri == 0) {
-    writeFilePath(fileEntries.begin(), fileEntries.end(), o,
-		  downloadResult->inMemoryDownload);
-  } else {
-    o << downloadResult->uri;
-    if(downloadResult->numUri > 1) {
-      o << " (" << downloadResult->numUri-1 << "more)";
-    }
-  }
+  writeFilePath(fileEntries.begin(), fileEntries.end(), o,
+		downloadResult->inMemoryDownload);
   return o.str();
 }
 
@@ -689,7 +662,7 @@ bool RequestGroupMan::isSameFileBeingDownloaded(RequestGroup* requestGroup) cons
   for(RequestGroups::const_iterator itr = _requestGroups.begin();
       itr != _requestGroups.end(); ++itr) {
     if((*itr).get() != requestGroup) {
-      std::deque<SharedHandle<FileEntry> > entries =
+      const std::vector<SharedHandle<FileEntry> >& entries =
 	(*itr)->getDownloadContext()->getFileEntries();
       std::transform(entries.begin(), entries.end(),
 		     std::back_inserter(files),
@@ -697,7 +670,7 @@ bool RequestGroupMan::isSameFileBeingDownloaded(RequestGroup* requestGroup) cons
     }
   }
   std::sort(files.begin(), files.end());
-  std::deque<SharedHandle<FileEntry> > entries =
+  const std::vector<SharedHandle<FileEntry> >& entries =
     requestGroup->getDownloadContext()->getFileEntries();
   return sameFilePathExists(files.begin(), files.end(),
 			    entries.begin(), entries.end());
@@ -788,22 +761,27 @@ bool RequestGroupMan::loadServerStat(const std::string& filename)
 
 bool RequestGroupMan::saveServerStat(const std::string& filename) const
 {
-  std::string tempfile = filename+"__temp";
-  std::ofstream out(tempfile.c_str(), std::ios::binary);
-  if(!out) {
-    _logger->error(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
-		   tempfile.c_str());
-    return false;
-  }
-  if (_serverStatMan->save(out)) {
-    out.close();
-    if (File(tempfile).renameTo(filename)) {
-      _logger->notice(MSG_SERVER_STAT_SAVED, filename.c_str());
-      return true;
+  std::string tempfile = filename;
+  tempfile += "__temp";
+  {
+    std::ofstream out(tempfile.c_str(), std::ios::binary);
+    if(!out) {
+      _logger->error(MSG_OPENING_WRITABLE_SERVER_STAT_FILE_FAILED,
+		     filename.c_str());
+      return false;
+    }
+    if(!_serverStatMan->save(out)) {
+      _logger->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
+      return false;
     }
   }
-  _logger->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
-  return false;
+  if(File(tempfile).renameTo(filename)) {
+    _logger->notice(MSG_SERVER_STAT_SAVED, filename.c_str());
+    return true;
+  } else {
+    _logger->error(MSG_WRITING_SERVER_STAT_FILE_FAILED, filename.c_str());
+    return false;
+  }
 }
 
 void RequestGroupMan::removeStaleServerStat(time_t timeout)
