@@ -742,14 +742,18 @@ void SocketCore::prepareSecureConnection()
     }
 #endif // HAVE_LIBSSL
 #ifdef HAVE_LIBGNUTLS
-    const int cert_type_priority[3] = { GNUTLS_CRT_X509,
-					GNUTLS_CRT_OPENPGP, 0
-    };
-    // while we do not support X509 certificate, most web servers require
-    // X509 stuff.
+    int r;
     gnutls_init(&sslSession, GNUTLS_CLIENT);
-    gnutls_set_default_priority(sslSession);
-    gnutls_kx_set_priority(sslSession, cert_type_priority);
+    // It seems err is not error message, but the argument string
+    // which causes syntax error.
+    const char* err;
+    // Disables TLS1.1 here because there are servers that don't
+    // understand TLS1.1.
+    r = gnutls_priority_set_direct(sslSession, "NORMAL:!VERS-TLS1.1", &err);
+    if(r != GNUTLS_E_SUCCESS) {
+      throw DL_ABORT_EX
+	(StringFormat(EX_SSL_INIT_FAILURE, gnutls_strerror(r)).str());
+    }
     // put the x509 credentials to the current session
     gnutls_credentials_set(sslSession, GNUTLS_CRD_CERTIFICATE,
 			   _tlsContext->getCertCred());
