@@ -154,15 +154,24 @@ const std::string PREF_EVENT_POLL("event-poll");
 const std::string V_EPOLL("epoll");
 const std::string V_SELECT("select");
 // value: 1*digit
-const std::string PREF_HTTP_SERVER_LISTEN_PORT("http-server-listen-port");
+const std::string PREF_XML_RPC_LISTEN_PORT("xml-rpc-listen-port");
 // value: true | false
-const std::string PREF_ENABLE_HTTP_SERVER("enable-http-server");
-// value: true | false
-const std::string PREF_RESET_URI("reset-uri");
+const std::string PREF_ENABLE_XML_RPC("enable-xml-rpc");
 // value: true | false
 const std::string PREF_DRY_RUN("dry-run");
 // value: true | false
 const std::string PREF_REUSE_URI("reuse-uri");
+// value: string
+const std::string PREF_XML_RPC_USER("xml-rpc-user");
+// value: string
+const std::string PREF_XML_RPC_PASSWD("xml-rpc-passwd");
+// value: 1*digit
+const std::string PREF_XML_RPC_MAX_REQUEST_SIZE("xml-rpc-max-request-size");
+// value: string
+const std::string PREF_ON_DOWNLOAD_START("on-download-start");
+const std::string PREF_ON_DOWNLOAD_STOP("on-download-stop");
+const std::string PREF_ON_DOWNLOAD_COMPLETE("on-download-complete");
+const std::string PREF_ON_DOWNLOAD_ERROR("on-download-error");
 
 /**
  * FTP related preferences
@@ -190,6 +199,8 @@ const std::string V_BASIC("basic");
 const std::string PREF_USER_AGENT("user-agent");
 // value: string that your file system recognizes as a file name.
 const std::string PREF_LOAD_COOKIES("load-cookies");
+// value: string that your file system recognizes as a file name.
+const std::string PREF_SAVE_COOKIES("save-cookies");
 // values: true | false
 const std::string PREF_ENABLE_HTTP_KEEP_ALIVE("enable-http-keep-alive");
 // values: true | false
@@ -292,6 +303,8 @@ const std::string PREF_BT_EXTERNAL_IP("bt-external-ip");
 const std::string PREF_INDEX_OUT("index-out");
 // values: 1*digit
 const std::string PREF_BT_TRACKER_INTERVAL("bt-tracker-interval");
+// values: 1*digit
+const std::string PREF_BT_STOP_TIMEOUT("bt-stop-timeout");
 
 /**
  * Metalink related preferences
