@@ -139,9 +139,10 @@ _(" --enable-direct-io[=true|false] Enable directI/O, which lowers cpu usage whi
   "                              allocating files.\n"\
   "                              Turn off if you encounter any error")
 #define TEXT_ALLOW_OVERWRITE \
-_(" --allow-overwrite=true|false If false, aria2 doesn't download a file which\n"\
-  "                              already exists but the corresponding .aria2 file\n"\
-  "                              doesn't exist.")
+_(" --allow-overwrite=true|false If false is given, and a file already exists but\n"\
+  "                              the corresponding control file (filename.aria2)\n"\
+  "                              doesn't exist, then aria2 will not re-download\n"\
+  "                              the file. See also --auto-file-renaming option.")
 #define TEXT_ALLOW_PIECE_LENGTH_CHANGE \
 _(" --allow-piece-length-change=true|false If false is given, aria2 aborts download\n"\
   "                              when a piece length is different from one in\n"\
@@ -217,6 +218,11 @@ _(" -j, --max-concurrent-downloads=N Set maximum number of parallel downloads fo
 #define TEXT_LOAD_COOKIES \
 _(" --load-cookies=FILE          Load Cookies from FILE using the Firefox3 format\n"\
   "                              and Mozilla/Firefox(1.x/2.x)/Netscape format.")
+#define TEXT_SAVE_COOKIES \
+_(" --save-cookies=FILE          Save Cookies to FILE in Mozilla/Firefox(1.x/2.x)/\n"\
+  "                              Netscape format. If FILE already exists, it is\n"\
+  "                              overwritten. Session Cookies are also saved and\n"\
+  "                              their expiry values are treated as 0.")
 #define TEXT_SHOW_FILES \
 _(" -S, --show-files             Print file listing of .torrent or .metalink file\n"\
   "                              and exit. More detailed information will be listed\n"\
@@ -276,7 +282,7 @@ _(" --seed-ratio=RATIO           Specify share ratio. Seed completed torrents\n"
   "                              this option, seeding ends when at least one of\n"\
   "                              the conditions is satisfied.")
 #define TEXT_PEER_ID_PREFIX \
-_(" --peer-id-prefix=PEERI_ID_PREFIX Specify the prefix of peer ID. The peer ID in\n"\
+_(" --peer-id-prefix=PEER_ID_PREFIX Specify the prefix of peer ID. The peer ID in\n"\
   "                              BitTorrent is 20 byte length. If more than 20\n"\
   "                              bytes are specified, only first 20\n"\
   "                              bytes are used. If less than 20 bytes are\n"\
@@ -478,17 +484,22 @@ _(" --use-head[=true|false]      Use HEAD method for the first request to the HT
   "                              server.")
 #define TEXT_EVENT_POLL \
 _(" --event-poll=POLL            Specify the method for polling events.")
-#define TEXT_HTTP_SERVER_LISTEN_PORT \
-  " --http-server-listen-port=PORT Specify a port number for the built-in HTTP\n"\
-  "                              Server to listen to."
-// Excluded from translation candidiates because it is subject to change.
-#define TEXT_ENABLE_HTTP_SERVER \
-  " --enable-http-server[=true|false] Enable the built-in HTTP server. Currently,\n"\
-  "                              this is the experimental feature and it just\n"\
-  "                              provides the current download progress. Use your\n"\
-  "                              web browser(console-based ones, such as elinks,\n"\
-  "                              w3m, are recommended) to connect the server and\n"\
-  "                              see what's what."
+#define TEXT_XML_RPC_LISTEN_PORT \
+_(" --xml-rpc-listen-port=PORT   Specify a port number for XML-RPC server to listen\n"\
+  "                              to.")
+#define TEXT_ENABLE_XML_RPC \
+_(" --enable-xml-rpc[=true|false] Enable XML-RPC server.\n"\
+  "                              It is strongly recommended to set username and\n"\
+  "                              password using --xml-rpc-user and --xml-rpc-passwd\n"\
+  "                              option. See also --xml-rpc-listen-port option.")
+#define TEXT_XML_RPC_MAX_REQUEST_SIZE \
+_(" --xml-rpc-max-request-size=SIZE Set max size of XML-RPC request. If aria2\n"\
+  "                              detects the request is more than SIZE bytes, it\n"\
+  "                              drops connection.")
+#define TEXT_XML_RPC_USER \
+_(" --xml-rpc-user=USER          Set XML-RPC user.")
+#define TEXT_XML_RPC_PASSWD \
+_(" --xml-rpc-passwd=PASSWD      Set XML-RPC password.")
 #define TEXT_BT_EXTERNAL_IP \
 _(" --bt-external-ip=IPADDRESS   Specify the external IP address to report to a\n"\
   "                              BitTorrent tracker. Although this function is\n"\
@@ -522,3 +533,32 @@ _(" --bt-tracker-interval=SEC    Set the interval in seconds between tracker\n"\
   "                              tracker. If 0 is set, aria2 determines interval\n"\
   "                              based on the response of tracker and the download\n"\
   "                              progress.")
+#define TEXT_ON_DOWNLOAD_COMPLETE \
+_(" --on-download-complete=COMMAND Set the command to be executed when download\n"\
+  "                              completes.\n"\
+  "                              See --on-download-start option for the\n"\
+  "                              requirement of COMMAND.\n"\
+  "                              See also --on-download-stop option.")
+#define TEXT_ON_DOWNLOAD_START \
+_(" --on-download-start=COMMAND  Set the command to be executed when download\n"\
+  "                              starts up. COMMAND must take just one argument and\n"\
+  "                              GID is passed to COMMAND as a first argument.")
+#define TEXT_ON_DOWNLOAD_ERROR \
+_(" --on-download-error=COMMAND  Set the command to be executed when download\n"\
+  "                              aborts due to error.\n"\
+  "                              See --on-download-start option for the\n"\
+  "                              requirement of COMMAND.\n"\
+  "                              See also --on-download-stop option.")
+#define TEXT_ON_DOWNLOAD_STOP \
+_(" --on-download-stop=COMMAND   Set the command to be executed when download\n"\
+  "                              stops. You can override the command to be executed\n"\
+  "                              for particular download result using\n"\
+  "                              --on-download-complete and --on-download-error. If\n"\
+  "                              they are specified, command specified in this\n"\
+  "                              option is not executed.\n"\
+  "                              See --on-download-start option for the\n"\
+  "                              requirement of COMMAND.")
+#define TEXT_BT_STOP_TIMEOUT \
+_(" --bt-stop-timeout=SEC        Stop BitTorrent download if download speed is 0 in\n"\
+  "                              consecutive SEC seconds. If 0 is given, this\n"\
+  "                              feature is disabled.")
