@@ -41,8 +41,9 @@ private:
 public:
   void setUp()
   {
-    _option.reset(new Option());    
-    _authConfigFactory.reset(new AuthConfigFactory(_option.get()));
+    _option.reset(new Option());
+    _option->put(PREF_HTTP_AUTH_CHALLENGE, V_TRUE);
+    _authConfigFactory.reset(new AuthConfigFactory());
   }
 
   void testGetStartByte();
@@ -68,13 +69,14 @@ void HttpRequestTest::testGetStartByte()
   HttpRequest httpRequest;
   SharedHandle<Piece> p(new Piece(1, 1024));
   SharedHandle<Segment> segment(new PiecedSegment(1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*10, 0));
 
   CPPUNIT_ASSERT_EQUAL((off_t)0LL, httpRequest.getStartByte());
 
   httpRequest.setSegment(segment);
+  httpRequest.setFileEntry(fileEntry);
   
   CPPUNIT_ASSERT_EQUAL((off_t)1024LL, httpRequest.getStartByte());
-
 }
 
 void HttpRequestTest::testGetEndByte()
@@ -86,6 +88,7 @@ void HttpRequestTest::testGetEndByte()
   HttpRequest httpRequest;
   SharedHandle<Piece> piece(new Piece(index, length));
   SharedHandle<Segment> segment(new PiecedSegment(segmentLength, piece));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", segmentLength*10, 0));
 
   CPPUNIT_ASSERT_EQUAL((off_t)0LL, httpRequest.getEndByte());
 
@@ -98,10 +101,16 @@ void HttpRequestTest::testGetEndByte()
   request->setPipeliningHint(true);
 
   httpRequest.setRequest(request);
+  httpRequest.setFileEntry(fileEntry);
 
   CPPUNIT_ASSERT_EQUAL((off_t)(segmentLength*index+length-1),
 		       httpRequest.getEndByte());
 
+  // The end byte of FileEntry are placed inside segment
+  fileEntry->setLength(segmentLength+100);
+
+  CPPUNIT_ASSERT_EQUAL((off_t)(segmentLength*index+100-1),
+		       httpRequest.getEndByte());
 
   request->setPipeliningHint(false);
 
@@ -119,12 +128,14 @@ void HttpRequestTest::testCreateRequest()
 
   p.reset(new Piece(0, 1024));
   SharedHandle<Segment> segment(new PiecedSegment(1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
 
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setFileEntry(fileEntry);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   // remove "Connection: close" and add end byte range
   request->setPipeliningHint(true);  
@@ -225,7 +236,8 @@ void HttpRequestTest::testCreateRequest()
   _option->put(PREF_HTTP_USER, "aria2user");
   _option->put(PREF_HTTP_PASSWD, "aria2passwd");
 
-  CPPUNIT_ASSERT(_authConfigFactory->activateBasicCred("localhost", "/"));
+  CPPUNIT_ASSERT(_authConfigFactory->activateBasicCred
+		 ("localhost", "/", _option.get()));
 
   expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -310,10 +322,13 @@ void HttpRequestTest::testCreateRequest_ftp()
   SharedHandle<Piece> p(new Piece(0, 1024*1024));
   SharedHandle<Segment> segment
     (new PiecedSegment(1024*1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
+
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setFileEntry(fileEntry);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   httpRequest.setProxyRequest(proxyRequest);
 
   std::string expectedText =
@@ -359,6 +374,7 @@ void HttpRequestTest::testCreateRequest_with_cookie()
   SharedHandle<Piece> p(new Piece(0, 1024*1024));
   SharedHandle<Segment> segment
     (new PiecedSegment(1024*1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 1024*1024*10, 0));
 
   Cookie cookie1("name1", "value1", "/archives", "localhost", false);
   Cookie cookie2("name2", "value2", "/archives/download", "localhost", false);
@@ -376,8 +392,9 @@ void HttpRequestTest::testCreateRequest_with_cookie()
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
+  httpRequest.setFileEntry(fileEntry);
   httpRequest.setCookieStorage(st);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2\r\n"
@@ -443,7 +460,7 @@ void HttpRequestTest::testCreateRequest_query()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string expectedText =
     "GET /wiki?id=9ad5109a-b8a5-4edf-9373-56a1c34ae138 HTTP/1.1\r\n"
@@ -466,7 +483,7 @@ void HttpRequestTest::testCreateRequest_head()
 
   HttpRequest httpRequest;
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   
   std::stringstream result(httpRequest.createRequest());
   std::string line;
@@ -546,11 +563,13 @@ void HttpRequestTest::testIsRangeSatisfied()
   request->setPipeliningHint(false); // default: false
   SharedHandle<Piece> p(new Piece(0, 1024*1024));
   SharedHandle<Segment> segment(new PiecedSegment(1024*1024, p));
+  SharedHandle<FileEntry> fileEntry(new FileEntry("file", 0, 0));
 
   HttpRequest httpRequest;
 
   httpRequest.setRequest(request);
   httpRequest.setSegment(segment);
+  httpRequest.setFileEntry(fileEntry);
 
   SharedHandle<Range> range(new Range());
 
@@ -568,11 +587,11 @@ void HttpRequestTest::testIsRangeSatisfied()
 
   CPPUNIT_ASSERT(httpRequest.isRangeSatisfied(range));
 
-  httpRequest.setEntityLength(entityLength-1);
+  fileEntry->setLength(entityLength-1);
 
   CPPUNIT_ASSERT(!httpRequest.isRangeSatisfied(range));
 
-  httpRequest.setEntityLength(entityLength);
+  fileEntry->setLength(entityLength);
 
   CPPUNIT_ASSERT(httpRequest.isRangeSatisfied(range));
 
@@ -597,15 +616,15 @@ void HttpRequestTest::testUserAgent()
   SharedHandle<Request> request(new Request());
   request->setUrl("http://localhost:8080/archives/aria2-1.0.0.tar.bz2");
 
-  SharedHandle<Piece> p(new Piece(0, 1024));
-  SharedHandle<Segment> segment(new PiecedSegment(1024, p));
+  //SharedHandle<Piece> p(new Piece(0, 1024));
+  //SharedHandle<Segment> segment(new PiecedSegment(1024, p));
 
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setSegment(segment);
+  //httpRequest.setSegment(segment);
   httpRequest.setUserAgent("aria2 (Linux)");
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
     "User-Agent: aria2 (Linux)\r\n"
@@ -640,7 +659,7 @@ void HttpRequestTest::testAddHeader()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   httpRequest.addHeader("X-ARIA2: v0.13\nX-ARIA2-DISTRIBUTE: enabled\n");
 
   std::string expectedText = "GET /archives/aria2-1.0.0.tar.bz2 HTTP/1.1\r\n"
@@ -668,7 +687,7 @@ void HttpRequestTest::testAddAcceptType()
   HttpRequest httpRequest;
   httpRequest.disableContentEncoding();
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
   httpRequest.addAcceptType(&acceptTypes[0],
 			    &acceptTypes[arrayLength(acceptTypes)]);
 
@@ -692,7 +711,7 @@ void HttpRequestTest::testEnableAcceptEncoding()
 
   HttpRequest httpRequest;
   httpRequest.setRequest(request);
-  httpRequest.setAuthConfigFactory(_authConfigFactory);
+  httpRequest.setAuthConfigFactory(_authConfigFactory, _option.get());
 
   std::string acceptEncodings;
 #ifdef HAVE_LIBZ
